==> unirest-java-core-4.0.7-sources.jar: kong/unirest/core/WebSocketResponse.java <==
/**
 * The MIT License
 *
 * Copyright for portions of unirest-java are held by Kong Inc (c) 2013.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package kong.unirest.core;

import java.net.http.WebSocket;
import java.util.concurrent.CompletableFuture;

public class WebSocketResponse {
    private final CompletableFuture<WebSocket> webSocketFuture;
    private final WebSocket.Listener listener;

    public WebSocketResponse(CompletableFuture<WebSocket> webSocketFuture, WebSocket.Listener listener) {
        this.webSocketFuture = webSocketFuture;
        this.listener = listener;
    }

    public CompletableFuture<WebSocket> socket(){
        return webSocketFuture;
    }

    public WebSocket.Listener listener(){
        return listener;
    }
}

==> unirest-java-core-4.2.2-sources.jar: kong/unirest/core/WebSocketResponse.java <==
/**
 * The MIT License
 *
 * Copyright for portions of unirest-java are held by Kong Inc (c) 2013.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package kong.unirest.core;

import java.net.http.WebSocket;
import java.util.concurrent.CompletableFuture;

/**
 * Just a silly little class that holds on to the socket and listener
 */
public class WebSocketResponse {
    private final CompletableFuture<WebSocket> webSocketFuture;
    private final WebSocket.Listener listener;

    /**
     * ctor
     * @param webSocketFuture the ws future
     * @param listener the listener
     */
    public WebSocketResponse(CompletableFuture<WebSocket> webSocketFuture, WebSocket.Listener listener) {
        this.webSocketFuture = webSocketFuture;
        this.listener = listener;
    }

    /**
     * @return the ws future
     */
    public CompletableFuture<WebSocket> socket(){
        return webSocketFuture;
    }

    /**
     * @return the listener
     */
    public WebSocket.Listener listener(){
        return listener;
    }
}
